@@ -1,3 +1,6 @@
 from .interface import Repository
 from .local import Local
 from .__version__ import __version__
+
+# trigger pluggy
+from . import hooks
